"{ Package: 'stx:goodies/sunit' }"

LibraryDefinition subclass:#stx_goodies_sunit
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'* Projects & Packages *'
!

!stx_goodies_sunit class methodsFor:'documentation'!

documentation
"
    Build- and package information for creation of the st/x standard library: stx_goodies_sunit
    This library contains the sunit test framework.
"
! !

!stx_goodies_sunit class methodsFor:'accessing - hg - settings'!

hgEnsureCopyrightMethod
    "If true, then #copyright method is automatically compiled in each class
     (but iff project definition defines it)

     Default is true (compile such method) but if the repository is mirror of CVS and
     you want to merge back to CVS at some point, you may want to not compile them
     to keep changes against CVS minimal"

    ^false

    "Created: / 09-07-2014 / 21:30:33 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

hgEnsureVersion_HGMethod
    "If true, then #version_HG method is automatically compiled in each class.

     Default is true (compile such method) but if the repository is mirror of CVS and
     you want to merge back to CVS at some point, you may want to not compile them
     to keep changes against CVS minimal. 

     If false, version_HG is compiled only in classes that has been modified
     and commited.

     Note that Mercurial can live without them
     just fine"

    ^false

    "Created: / 09-07-2014 / 21:30:43 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

hgRemoveContainesForDeletedClasses
    "If true, then containers for removed classes are __AUTOMATICALLY__ removed from the
     repositoru. If false, obsolete containes are kept.

     Default is true (remove obsolete containers) but if the repository is mirror of CVS and
     you want to merge back to CVS at some point, you may want to return false to avoid deletions
     of obsolete files. Usefull when branching off an old CVS repo with loads of mess."

    ^false

    "Created: / 09-07-2014 / 21:30:54 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!stx_goodies_sunit class methodsFor:'description'!

excludedFromPreRequisites
    "list all packages which should be ignored in the automatic
     preRequisites scan. See #preRequisites for more."

    ^ #(
    )
!

mandatoryPreRequisites
    "list all required mandatory packages.
     Packages are mandatory, if they contain superclasses of the package's classes
     or classes which are extended by this package.
     This list can be maintained manually or (better) generated and
     updated by scanning the superclass hierarchies
     (the browser has a menu function for that)
     However, often too much is found, and you may want to explicitely
     exclude individual packages in the #excludedFromPreRequisites method."

    ^ #(
        #'stx:libbasic'    "String - extended "
        #'stx:libview2'    "ApplicationModel - superclass of TestRunner "
    )
!

referencedPreRequisites
    "list all packages containing classes referenced by the packages's members.
     This list can be maintained manually or (better) generated and
     updated by looking for global variable accesses
     (the browser has a menu function for that)
     However, often too much is found, and you may want to explicitely
     exclude individual packages in the #excludedFromPreRequisites method."

    ^ #(
        #'stx:libbasic2'    "SplittingWriteStream - referenced by TestResultStX>>performCase: "
        #'stx:libview'    "Color - referenced by TestRunner>>displayNormalColorInProgress "
    )
! !

!stx_goodies_sunit class methodsFor:'description - contents'!

classNamesAndAttributes
    "lists the classes which are to be included in the project.
     Each entry in the list may be: a single class-name (symbol),
     or an array-literal consisting of class name and attributes.
     Attributes are: #autoload or #<os> where os is one of win32, unix,..."

    ^ #(
        "<className> or (<className> attributes...) in load order"
        (ExampleTestResource autoload)
        SUnitDelay
        SUnitNameResolver
        TestAsserter
        TestFailure
        TestResult
        TestResultReporter
        TestRunner
        TestSuite
        TestSuitesScripter
        #'stx_goodies_sunit'
        ResumableTestFailure
        TestCase
        TestCaseWithArguments
        TestResource
        (ExampleSetTest autoload)
        (ResumableTestFailureTestCase autoload)
        (SUnitTest autoload)
        (SimpleTestResource autoload)
        (SimpleTestResourceTestCase autoload)
        (FailingTestResourceTestCase autoload)
        (ManyTestResourceTestCase autoload)
        (SimpleTestResourceA autoload)
        (SimpleTestResourceA1 autoload)
        (SimpleTestResourceA2 autoload)
        (SimpleTestResourceB autoload)
        (SimpleTestResourceB1 autoload)
        (SimpleTestResourceCircular autoload)
        (SimpleTestResourceCircular1 autoload)
        (CircularTestResourceTestCase autoload)
        TestCaseOutcome
        TestResultStX
        TestResultForRunWithDebug
        (SUnitTests2 autoload)
        TestCoverageReporter
        MetricsReporter
        TestSkipped
        (TestSuitesScriptTest autoload)
        (TestSuitesHierarchyScriptTest autoload)
        (TestSuitesCompoundScriptTest autoload)      
    )

    "Modified: / 09-07-2014 / 21:32:54 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

extensionMethodNames
    "lists the extension methods which are to be included in the project.
     Entries are 2-element array literals, consisting of class-name and selector."

    ^ #(
        Block sunitEnsure:
        Block sunitOn:do:
        GenericException sunitAnnounce:toResult:
        GenericException sunitExitWith:
        Object sunitAddDependent:
        Object sunitChanged:
        Object sunitRemoveDependent:
        String sunitAsSymbol
        String sunitMatch:
        String sunitSubStrings
        Symbol sunitAsClass
        'GenericException class' sunitSignalWith:
        Behavior sunitSelectors
        Class sunitName
    )
! !

!stx_goodies_sunit class methodsFor:'description - project information'!

applicationIconFileName
    "Return the name (without suffix) of an icon-file (the app's icon); will be included in the rc-resource file"

    ^ nil
    "/ ^ self applicationName
!

companyName
    "Return a companyname which will appear in <lib>.rc"

    ^ 'eXept Software AG'
!

description
    "Return a description string which will appear in nt.def / bc.def"

    ^ 'Smalltalk/X Unit Testing'
!

legalCopyright
    "Return a copyright string which will appear in <lib>.rc"

    ^ 'Copyright eXept Software AG 1998-2007'

    "Modified: / 08-11-2007 / 16:57:33 / cg"
!

productName
    "Return a product name which will appear in <lib>.rc"

    ^ 'Smalltalk/X'
! !

!stx_goodies_sunit class methodsFor:'description - svn'!

svnRevisionNr
    "Return a SVN revision number of myself.
     This number is updated after a commit"

    ^ "$SVN-Revision:"'Nicht versioniertes Verzeichnis'"$"
! !

!stx_goodies_sunit class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/goodies/sunit/stx_goodies_sunit.st,v 1.41 2014-03-23 21:08:48 cg Exp $'
!

version_CVS
    ^ '$Header: /cvs/stx/stx/goodies/sunit/stx_goodies_sunit.st,v 1.41 2014-03-23 21:08:48 cg Exp $'
!

version_HG
    ^ '$Changeset: <not expanded> $'
!

version_SVN
    ^ '$Id: stx_goodies_sunit.st,v 1.41 2014-03-23 21:08:48 cg Exp $'
! !

